@@ -29,7 +29,7 @@ void HistoryInfoWindow::load(QString name, QString group)
     int j = 0;
     QString set;
 
-    setWindowTitle(name);
+    setWindowTitle(name + "/" + group);
 
     list = xml->getHistoryByExercise(name);
 
